%% - Scaling at Aspect Ratio: 2.8

% N = 5E5 for labyrinth at a_s = 85, AR = 2.8
% We require N =  sqrt(ScalingFactor) * N_labyrinth = 1E5/8E4
% This implies ScalingFactor = (1/5)^2/(0.8/5)^2
% We have to scale the Horizontal Trap Frequency by 1/ScalingFactor
% The Vertical Trap Frequency will still be AR * Horizontal Trap Frequency

%% - N = 1E5

ScalingFactor                         = (1/5)^2;

OptionsStruct = struct;

OptionsStruct.NumberOfAtoms           = sqrt(ScalingFactor) * 5E5;
OptionsStruct.DipolarPolarAngle       = deg2rad(0);
OptionsStruct.DipolarAzimuthAngle     = 0;
OptionsStruct.ScatteringLength        = 85;

AspectRatio                           = 2.8;
HorizontalTrapFrequency               = 125/ScalingFactor;
VerticalTrapFrequency                 = AspectRatio * HorizontalTrapFrequency;
OptionsStruct.TrapFrequencies         = [HorizontalTrapFrequency, HorizontalTrapFrequency, VerticalTrapFrequency];
OptionsStruct.TrapPotentialType       = 'Harmonic';

OptionsStruct.NumberOfGridPoints      = [128, 128, 64];
OptionsStruct.Dimensions              = [4, 4, 4];
OptionsStruct.UseApproximationForLHY  = true;
OptionsStruct.IncludeDDICutOff        = true;
OptionsStruct.CutoffType              = 'Cylindrical';
OptionsStruct.SimulationMode          = 'ImaginaryTimeEvolution'; % 'ImaginaryTimeEvolution' | 'RealTimeEvolution'
OptionsStruct.TimeStepSize            = 1E-4;            % in s
OptionsStruct.MinimumTimeStepSize     = 2E-6;           % in s
OptionsStruct.TimeCutOff              = 2E6;             % in s
OptionsStruct.EnergyTolerance         = 5E-10;
OptionsStruct.ResidualTolerance       = 1E-08;
OptionsStruct.NoiseScaleFactor        = 0.01;

OptionsStruct.PlotLive                = false;
OptionsStruct.JobNumber               = 0;
OptionsStruct.RunOnGPU                = true;
OptionsStruct.SaveData                = true;
OptionsStruct.SaveDirectory           = sprintf('./Results/Data_3D/ApproximateLHY/AspectRatio%s', strrep(num2str(AspectRatio), '.', '_'));
options                               = Helper.convertstruct2cell(OptionsStruct);
clear OptionsStruct

sim                                   = Simulator.DipolarGas(options{:});
pot                                   = Simulator.Potentials(options{:});
sim.Potential                         = pot.trap(); 

%-% Run Simulation %-%
[Params, Transf, psi, V, VDk]         = sim.run();

%% - N = 8E4

ScalingFactor                         = (0.8/5)^2;

OptionsStruct = struct;

OptionsStruct.NumberOfAtoms           = sqrt(ScalingFactor) * 5E5;
OptionsStruct.DipolarPolarAngle       = deg2rad(0);
OptionsStruct.DipolarAzimuthAngle     = 0;
OptionsStruct.ScatteringLength        = 85;

AspectRatio                           = 2.8;
HorizontalTrapFrequency               = 125/ScalingFactor;
VerticalTrapFrequency                 = AspectRatio * HorizontalTrapFrequency;
OptionsStruct.TrapFrequencies         = [HorizontalTrapFrequency, HorizontalTrapFrequency, VerticalTrapFrequency];
OptionsStruct.TrapPotentialType       = 'Harmonic';

OptionsStruct.NumberOfGridPoints      = [128, 128, 64];
OptionsStruct.Dimensions              = [4, 4, 4];
OptionsStruct.UseApproximationForLHY  = true;
OptionsStruct.IncludeDDICutOff        = true;
OptionsStruct.CutoffType              = 'Cylindrical';
OptionsStruct.SimulationMode          = 'ImaginaryTimeEvolution'; % 'ImaginaryTimeEvolution' | 'RealTimeEvolution'
OptionsStruct.TimeStepSize            = 1E-4;            % in s
OptionsStruct.MinimumTimeStepSize     = 2E-6;           % in s
OptionsStruct.TimeCutOff              = 2E6;             % in s
OptionsStruct.EnergyTolerance         = 5E-10;
OptionsStruct.ResidualTolerance       = 1E-08;
OptionsStruct.NoiseScaleFactor        = 0.01;

OptionsStruct.PlotLive                = false;
OptionsStruct.JobNumber               = 1;
OptionsStruct.RunOnGPU                = true;
OptionsStruct.SaveData                = true;
OptionsStruct.SaveDirectory           = sprintf('./Results/Data_3D/ApproximateLHY/AspectRatio%s', strrep(num2str(AspectRatio), '.', '_'));
options                               = Helper.convertstruct2cell(OptionsStruct);
clear OptionsStruct

sim                                   = Simulator.DipolarGas(options{:});
pot                                   = Simulator.Potentials(options{:});
sim.Potential                         = pot.trap(); 

%-% Run Simulation %-%
[Params, Transf, psi, V, VDk]         = sim.run();